const API_URL = 'http://127.0.0.1/genieacs';
const qs = require('querystring');
const url = require("url");
const http = require(API_URL.split(":", 1)[0]);
const logger = require('../../lib/logger');

function portaxCallback(args, callback) {

	let params = JSON.parse(args[0]);

	const uri = API_URL;

	let postData = qs.stringify(params);

	let options = url.parse(uri);

	options.method = "POST";
	options.headers = {
		"Accept": 'application/json',
		"Content-Type": 'application/x-www-form-urlencoded',
		"Content-Length": Buffer.byteLength(postData)
		};

	logger.info({message: 'post callback ' + params.id});

	let request = http.request(options, function (response) {

		if (response.statusCode == 404) {
			return callback(null, null);
		}

		if (response.statusCode >= 400) {
			return callback(new Error("Unexpected error. Response Code: " +
			response.statusCode + '. Status Message: ' + response.statusMessage + '. t: ' + typeof response.statusCode));
		}

		let data = "";

		response.on("data", function(d) {
			data = data + d.toString();
		});

		response.on("end", function () {
			logger.info({message: 'post callback response: ' + data});
			return callback(null,data);
		});

	});
	
	request.on("error", function (err) {
		logger.info({message: 'post callback error: ' + err});
		request.abort();
		return callback(err);
	});
	
	request.on("socket", function(socket) {
		socket.setTimeout(5000);
		return socket.on('timeout', function() {
			logger.info({message: 'socket timeout'});
			request.abort();
		});
	});

	request.write(postData);
	request.end();

}

function portaxGetConfig(args, callback) {

	if( null == args) {
		return callback(new Error('undefined arguments'));
	}

	let genieacsId = args[0];

	logger.info({message: 'Fetch config', id: genieacsId});

	const uri = API_URL + "?id=" + genieacsId;

	let options = url.parse(uri);
	options.headers = { accept: 'application/json', "content-type": 'application/json' };

	let request = http.get(options, function (response) {
		if (response.statusCode == 404) {
			return callback(null, null);
		}

		if (response.statusCode >= 400) {
			return callback(new Error("Unexpected error. Response Code: " +
			response.statusCode + '. Status Message: ' + response.statusMessage + '. t: ' + typeof response.statusCode));
		}

		let data = "";

		response.on("data", function(d) {
			data = data + d.toString();
		});

		response.on("end", function () {
			if(data == "") {
				return callback(null,null);
			}
			logger.info({message: 'Config fetched', id: genieacsId, data: data});
			let result = JSON.parse(data);
			return callback(null,result);
		});

	});
	
	request.on("socket", function(socket) {
		socket.setTimeout(5000);
		return socket.on('timeout', function() {
			logger.info({message: 'socket timeout'});
			request.abort();
		});
	});

	request.on("error", function (err) {
		logger.info({message: 'get config error: ' + err});
		request.abort();
		return callback(err);
	});

}

exports.portaxCallback = portaxCallback;
exports.portaxGetConfig = portaxGetConfig;

